@@ -26,15 +26,15 @@
 #endif
 
 #include <glib-object.h>
+#include <gmodule.h>
 #include <enchant.h>
 #include <gspell/gspell-language.h>
-#include <gspell/gspell-version.h>
 
 G_BEGIN_DECLS
 
 #define GSPELL_TYPE_CHECKER (gspell_checker_get_type ())
 
-GSPELL_AVAILABLE_IN_ALL
+G_MODULE_EXPORT
 G_DECLARE_DERIVABLE_TYPE (GspellChecker, gspell_checker,
 			  GSPELL, CHECKER,
 			  GObject)
@@ -79,56 +79,54 @@ struct _GspellCheckerClass
 	gpointer padding[12];
 };
 
-GSPELL_AVAILABLE_IN_ALL
+G_MODULE_EXPORT
 GQuark		gspell_checker_error_quark		(void);
 
-GSPELL_AVAILABLE_IN_ALL
+G_MODULE_EXPORT
 GspellChecker *	gspell_checker_new			(const GspellLanguage *language);
 
-GSPELL_AVAILABLE_IN_ALL
+G_MODULE_EXPORT
 void		gspell_checker_set_language		(GspellChecker        *checker,
 							 const GspellLanguage *language);
 
-GSPELL_AVAILABLE_IN_ALL
+G_MODULE_EXPORT
 const GspellLanguage *
 		gspell_checker_get_language		(GspellChecker *checker);
 
-GSPELL_AVAILABLE_IN_ALL
+G_MODULE_EXPORT
 gboolean	gspell_checker_check_word		(GspellChecker  *checker,
 							 const gchar    *word,
 							 gssize          word_length,
 							 GError        **error);
 
-GSPELL_AVAILABLE_IN_ALL
+G_MODULE_EXPORT
 GSList *	gspell_checker_get_suggestions		(GspellChecker *checker,
 							 const gchar   *word,
 							 gssize         word_length);
 
-GSPELL_AVAILABLE_IN_ALL
+G_MODULE_EXPORT
 void		gspell_checker_add_word_to_personal	(GspellChecker *checker,
 							 const gchar   *word,
 							 gssize         word_length);
 
-GSPELL_AVAILABLE_IN_ALL
+G_MODULE_EXPORT
 void		gspell_checker_add_word_to_session	(GspellChecker *checker,
 							 const gchar   *word,
 							 gssize         word_length);
 
-GSPELL_AVAILABLE_IN_ALL
+G_MODULE_EXPORT
 void		gspell_checker_clear_session		(GspellChecker *checker);
 
-GSPELL_AVAILABLE_IN_ALL
+G_MODULE_EXPORT
 void		gspell_checker_set_correction		(GspellChecker *checker,
 							 const gchar   *word,
 							 gssize         word_length,
 							 const gchar   *replacement,
 							 gssize         replacement_length);
 
-GSPELL_AVAILABLE_IN_1_6
+G_MODULE_EXPORT
 EnchantDict *	gspell_checker_get_enchant_dict		(GspellChecker *checker);
 
 G_END_DECLS
 
 #endif  /* GSPELL_CHECKER_H */
-
-/* ex:set ts=8 noet: */
